# Besiktas

Besiktas CLI!

## Installation

```shell
$ pip install besiktas
```

## Usage
Main Page
```shell summary
$ besiktas
```
List of Players
```shell footballers
$ besiktas -kadro
```
List of Top Scorers
```shell footballers
$ besiktas -stats
```

